// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/sessions/ioMappings.proto

package ubii.sessions;

public final class IoMappings {
  private IoMappings() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface TopicInputMappingOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.TopicInputMapping)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string input_name = 1;</code>
     */
    java.lang.String getInputName();
    /**
     * <code>string input_name = 1;</code>
     */
    com.google.protobuf.ByteString
        getInputNameBytes();

    /**
     * <code>string topic = 2;</code>
     */
    java.lang.String getTopic();
    /**
     * <code>string topic = 2;</code>
     */
    com.google.protobuf.ByteString
        getTopicBytes();

    /**
     * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
     */
    boolean hasTopicMux();
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMux getTopicMux();
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getTopicMuxOrBuilder();

    public ubii.sessions.IoMappings.TopicInputMapping.TopicSourceCase getTopicSourceCase();
  }
  /**
   * Protobuf type {@code ubii.sessions.TopicInputMapping}
   */
  public  static final class TopicInputMapping extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.TopicInputMapping)
      TopicInputMappingOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicInputMapping.newBuilder() to construct.
    private TopicInputMapping(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicInputMapping() {
      inputName_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicInputMapping(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              inputName_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();
              topicSourceCase_ = 2;
              topicSource_ = s;
              break;
            }
            case 26: {
              ubii.devices.TopicMuxOuterClass.TopicMux.Builder subBuilder = null;
              if (topicSourceCase_ == 3) {
                subBuilder = ((ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_).toBuilder();
              }
              topicSource_ =
                  input.readMessage(ubii.devices.TopicMuxOuterClass.TopicMux.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_);
                topicSource_ = subBuilder.buildPartial();
              }
              topicSourceCase_ = 3;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMapping_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMapping_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.IoMappings.TopicInputMapping.class, ubii.sessions.IoMappings.TopicInputMapping.Builder.class);
    }

    private int topicSourceCase_ = 0;
    private java.lang.Object topicSource_;
    public enum TopicSourceCase
        implements com.google.protobuf.Internal.EnumLite {
      TOPIC(2),
      TOPIC_MUX(3),
      TOPICSOURCE_NOT_SET(0);
      private final int value;
      private TopicSourceCase(int value) {
        this.value = value;
      }
      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static TopicSourceCase valueOf(int value) {
        return forNumber(value);
      }

      public static TopicSourceCase forNumber(int value) {
        switch (value) {
          case 2: return TOPIC;
          case 3: return TOPIC_MUX;
          case 0: return TOPICSOURCE_NOT_SET;
          default: return null;
        }
      }
      public int getNumber() {
        return this.value;
      }
    };

    public TopicSourceCase
    getTopicSourceCase() {
      return TopicSourceCase.forNumber(
          topicSourceCase_);
    }

    public static final int INPUT_NAME_FIELD_NUMBER = 1;
    private volatile java.lang.Object inputName_;
    /**
     * <code>string input_name = 1;</code>
     */
    public java.lang.String getInputName() {
      java.lang.Object ref = inputName_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        inputName_ = s;
        return s;
      }
    }
    /**
     * <code>string input_name = 1;</code>
     */
    public com.google.protobuf.ByteString
        getInputNameBytes() {
      java.lang.Object ref = inputName_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        inputName_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int TOPIC_FIELD_NUMBER = 2;
    /**
     * <code>string topic = 2;</code>
     */
    public java.lang.String getTopic() {
      java.lang.Object ref = "";
      if (topicSourceCase_ == 2) {
        ref = topicSource_;
      }
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        if (topicSourceCase_ == 2) {
          topicSource_ = s;
        }
        return s;
      }
    }
    /**
     * <code>string topic = 2;</code>
     */
    public com.google.protobuf.ByteString
        getTopicBytes() {
      java.lang.Object ref = "";
      if (topicSourceCase_ == 2) {
        ref = topicSource_;
      }
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        if (topicSourceCase_ == 2) {
          topicSource_ = b;
        }
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int TOPIC_MUX_FIELD_NUMBER = 3;
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
     */
    public boolean hasTopicMux() {
      return topicSourceCase_ == 3;
    }
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMux getTopicMux() {
      if (topicSourceCase_ == 3) {
         return (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_;
      }
      return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getTopicMuxOrBuilder() {
      if (topicSourceCase_ == 3) {
         return (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_;
      }
      return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getInputNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, inputName_);
      }
      if (topicSourceCase_ == 2) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, topicSource_);
      }
      if (topicSourceCase_ == 3) {
        output.writeMessage(3, (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getInputNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, inputName_);
      }
      if (topicSourceCase_ == 2) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(2, topicSource_);
      }
      if (topicSourceCase_ == 3) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.IoMappings.TopicInputMapping)) {
        return super.equals(obj);
      }
      ubii.sessions.IoMappings.TopicInputMapping other = (ubii.sessions.IoMappings.TopicInputMapping) obj;

      boolean result = true;
      result = result && getInputName()
          .equals(other.getInputName());
      result = result && getTopicSourceCase().equals(
          other.getTopicSourceCase());
      if (!result) return false;
      switch (topicSourceCase_) {
        case 2:
          result = result && getTopic()
              .equals(other.getTopic());
          break;
        case 3:
          result = result && getTopicMux()
              .equals(other.getTopicMux());
          break;
        case 0:
        default:
      }
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + INPUT_NAME_FIELD_NUMBER;
      hash = (53 * hash) + getInputName().hashCode();
      switch (topicSourceCase_) {
        case 2:
          hash = (37 * hash) + TOPIC_FIELD_NUMBER;
          hash = (53 * hash) + getTopic().hashCode();
          break;
        case 3:
          hash = (37 * hash) + TOPIC_MUX_FIELD_NUMBER;
          hash = (53 * hash) + getTopicMux().hashCode();
          break;
        case 0:
        default:
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicInputMapping parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.IoMappings.TopicInputMapping prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.TopicInputMapping}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.TopicInputMapping)
        ubii.sessions.IoMappings.TopicInputMappingOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMapping_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMapping_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.IoMappings.TopicInputMapping.class, ubii.sessions.IoMappings.TopicInputMapping.Builder.class);
      }

      // Construct using ubii.sessions.IoMappings.TopicInputMapping.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        inputName_ = "";

        topicSourceCase_ = 0;
        topicSource_ = null;
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMapping_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicInputMapping getDefaultInstanceForType() {
        return ubii.sessions.IoMappings.TopicInputMapping.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicInputMapping build() {
        ubii.sessions.IoMappings.TopicInputMapping result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicInputMapping buildPartial() {
        ubii.sessions.IoMappings.TopicInputMapping result = new ubii.sessions.IoMappings.TopicInputMapping(this);
        result.inputName_ = inputName_;
        if (topicSourceCase_ == 2) {
          result.topicSource_ = topicSource_;
        }
        if (topicSourceCase_ == 3) {
          if (topicMuxBuilder_ == null) {
            result.topicSource_ = topicSource_;
          } else {
            result.topicSource_ = topicMuxBuilder_.build();
          }
        }
        result.topicSourceCase_ = topicSourceCase_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.IoMappings.TopicInputMapping) {
          return mergeFrom((ubii.sessions.IoMappings.TopicInputMapping)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.IoMappings.TopicInputMapping other) {
        if (other == ubii.sessions.IoMappings.TopicInputMapping.getDefaultInstance()) return this;
        if (!other.getInputName().isEmpty()) {
          inputName_ = other.inputName_;
          onChanged();
        }
        switch (other.getTopicSourceCase()) {
          case TOPIC: {
            topicSourceCase_ = 2;
            topicSource_ = other.topicSource_;
            onChanged();
            break;
          }
          case TOPIC_MUX: {
            mergeTopicMux(other.getTopicMux());
            break;
          }
          case TOPICSOURCE_NOT_SET: {
            break;
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.IoMappings.TopicInputMapping parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.IoMappings.TopicInputMapping) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int topicSourceCase_ = 0;
      private java.lang.Object topicSource_;
      public TopicSourceCase
          getTopicSourceCase() {
        return TopicSourceCase.forNumber(
            topicSourceCase_);
      }

      public Builder clearTopicSource() {
        topicSourceCase_ = 0;
        topicSource_ = null;
        onChanged();
        return this;
      }


      private java.lang.Object inputName_ = "";
      /**
       * <code>string input_name = 1;</code>
       */
      public java.lang.String getInputName() {
        java.lang.Object ref = inputName_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          inputName_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string input_name = 1;</code>
       */
      public com.google.protobuf.ByteString
          getInputNameBytes() {
        java.lang.Object ref = inputName_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          inputName_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string input_name = 1;</code>
       */
      public Builder setInputName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        inputName_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string input_name = 1;</code>
       */
      public Builder clearInputName() {
        
        inputName_ = getDefaultInstance().getInputName();
        onChanged();
        return this;
      }
      /**
       * <code>string input_name = 1;</code>
       */
      public Builder setInputNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        inputName_ = value;
        onChanged();
        return this;
      }

      /**
       * <code>string topic = 2;</code>
       */
      public java.lang.String getTopic() {
        java.lang.Object ref = "";
        if (topicSourceCase_ == 2) {
          ref = topicSource_;
        }
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          if (topicSourceCase_ == 2) {
            topicSource_ = s;
          }
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string topic = 2;</code>
       */
      public com.google.protobuf.ByteString
          getTopicBytes() {
        java.lang.Object ref = "";
        if (topicSourceCase_ == 2) {
          ref = topicSource_;
        }
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          if (topicSourceCase_ == 2) {
            topicSource_ = b;
          }
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string topic = 2;</code>
       */
      public Builder setTopic(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  topicSourceCase_ = 2;
        topicSource_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string topic = 2;</code>
       */
      public Builder clearTopic() {
        if (topicSourceCase_ == 2) {
          topicSourceCase_ = 0;
          topicSource_ = null;
          onChanged();
        }
        return this;
      }
      /**
       * <code>string topic = 2;</code>
       */
      public Builder setTopicBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        topicSourceCase_ = 2;
        topicSource_ = value;
        onChanged();
        return this;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> topicMuxBuilder_;
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public boolean hasTopicMux() {
        return topicSourceCase_ == 3;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux getTopicMux() {
        if (topicMuxBuilder_ == null) {
          if (topicSourceCase_ == 3) {
            return (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_;
          }
          return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
        } else {
          if (topicSourceCase_ == 3) {
            return topicMuxBuilder_.getMessage();
          }
          return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public Builder setTopicMux(ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (topicMuxBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          topicSource_ = value;
          onChanged();
        } else {
          topicMuxBuilder_.setMessage(value);
        }
        topicSourceCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public Builder setTopicMux(
          ubii.devices.TopicMuxOuterClass.TopicMux.Builder builderForValue) {
        if (topicMuxBuilder_ == null) {
          topicSource_ = builderForValue.build();
          onChanged();
        } else {
          topicMuxBuilder_.setMessage(builderForValue.build());
        }
        topicSourceCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public Builder mergeTopicMux(ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (topicMuxBuilder_ == null) {
          if (topicSourceCase_ == 3 &&
              topicSource_ != ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance()) {
            topicSource_ = ubii.devices.TopicMuxOuterClass.TopicMux.newBuilder((ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_)
                .mergeFrom(value).buildPartial();
          } else {
            topicSource_ = value;
          }
          onChanged();
        } else {
          if (topicSourceCase_ == 3) {
            topicMuxBuilder_.mergeFrom(value);
          }
          topicMuxBuilder_.setMessage(value);
        }
        topicSourceCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public Builder clearTopicMux() {
        if (topicMuxBuilder_ == null) {
          if (topicSourceCase_ == 3) {
            topicSourceCase_ = 0;
            topicSource_ = null;
            onChanged();
          }
        } else {
          if (topicSourceCase_ == 3) {
            topicSourceCase_ = 0;
            topicSource_ = null;
          }
          topicMuxBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux.Builder getTopicMuxBuilder() {
        return getTopicMuxFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getTopicMuxOrBuilder() {
        if ((topicSourceCase_ == 3) && (topicMuxBuilder_ != null)) {
          return topicMuxBuilder_.getMessageOrBuilder();
        } else {
          if (topicSourceCase_ == 3) {
            return (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_;
          }
          return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 3;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> 
          getTopicMuxFieldBuilder() {
        if (topicMuxBuilder_ == null) {
          if (!(topicSourceCase_ == 3)) {
            topicSource_ = ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
          }
          topicMuxBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder>(
                  (ubii.devices.TopicMuxOuterClass.TopicMux) topicSource_,
                  getParentForChildren(),
                  isClean());
          topicSource_ = null;
        }
        topicSourceCase_ = 3;
        onChanged();;
        return topicMuxBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.TopicInputMapping)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.TopicInputMapping)
    private static final ubii.sessions.IoMappings.TopicInputMapping DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.IoMappings.TopicInputMapping();
    }

    public static ubii.sessions.IoMappings.TopicInputMapping getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicInputMapping>
        PARSER = new com.google.protobuf.AbstractParser<TopicInputMapping>() {
      @java.lang.Override
      public TopicInputMapping parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicInputMapping(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicInputMapping> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicInputMapping> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.IoMappings.TopicInputMapping getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface TopicInputMappingListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.TopicInputMappingList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    java.util.List<ubii.sessions.IoMappings.TopicInputMapping> 
        getElementsList();
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    ubii.sessions.IoMappings.TopicInputMapping getElements(int index);
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    java.util.List<? extends ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    ubii.sessions.IoMappings.TopicInputMappingOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.sessions.TopicInputMappingList}
   */
  public  static final class TopicInputMappingList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.TopicInputMappingList)
      TopicInputMappingListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicInputMappingList.newBuilder() to construct.
    private TopicInputMappingList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicInputMappingList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicInputMappingList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicInputMapping>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.sessions.IoMappings.TopicInputMapping.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMappingList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMappingList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.IoMappings.TopicInputMappingList.class, ubii.sessions.IoMappings.TopicInputMappingList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.sessions.IoMappings.TopicInputMapping> elements_;
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    public java.util.List<ubii.sessions.IoMappings.TopicInputMapping> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    public java.util.List<? extends ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    public ubii.sessions.IoMappings.TopicInputMapping getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
     */
    public ubii.sessions.IoMappings.TopicInputMappingOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.IoMappings.TopicInputMappingList)) {
        return super.equals(obj);
      }
      ubii.sessions.IoMappings.TopicInputMappingList other = (ubii.sessions.IoMappings.TopicInputMappingList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicInputMappingList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.IoMappings.TopicInputMappingList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.TopicInputMappingList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.TopicInputMappingList)
        ubii.sessions.IoMappings.TopicInputMappingListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMappingList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMappingList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.IoMappings.TopicInputMappingList.class, ubii.sessions.IoMappings.TopicInputMappingList.Builder.class);
      }

      // Construct using ubii.sessions.IoMappings.TopicInputMappingList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicInputMappingList_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicInputMappingList getDefaultInstanceForType() {
        return ubii.sessions.IoMappings.TopicInputMappingList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicInputMappingList build() {
        ubii.sessions.IoMappings.TopicInputMappingList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicInputMappingList buildPartial() {
        ubii.sessions.IoMappings.TopicInputMappingList result = new ubii.sessions.IoMappings.TopicInputMappingList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.IoMappings.TopicInputMappingList) {
          return mergeFrom((ubii.sessions.IoMappings.TopicInputMappingList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.IoMappings.TopicInputMappingList other) {
        if (other == ubii.sessions.IoMappings.TopicInputMappingList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.IoMappings.TopicInputMappingList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.IoMappings.TopicInputMappingList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.sessions.IoMappings.TopicInputMapping> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicInputMapping>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicInputMapping, ubii.sessions.IoMappings.TopicInputMapping.Builder, ubii.sessions.IoMappings.TopicInputMappingOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicInputMapping> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.IoMappings.TopicInputMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.IoMappings.TopicInputMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder addElements(ubii.sessions.IoMappings.TopicInputMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.IoMappings.TopicInputMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder addElements(
          ubii.sessions.IoMappings.TopicInputMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.IoMappings.TopicInputMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.sessions.IoMappings.TopicInputMapping> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMappingOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public java.util.List<? extends ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.sessions.IoMappings.TopicInputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.sessions.IoMappings.TopicInputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping elements = 1;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicInputMapping.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicInputMapping, ubii.sessions.IoMappings.TopicInputMapping.Builder, ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.IoMappings.TopicInputMapping, ubii.sessions.IoMappings.TopicInputMapping.Builder, ubii.sessions.IoMappings.TopicInputMappingOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.TopicInputMappingList)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.TopicInputMappingList)
    private static final ubii.sessions.IoMappings.TopicInputMappingList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.IoMappings.TopicInputMappingList();
    }

    public static ubii.sessions.IoMappings.TopicInputMappingList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicInputMappingList>
        PARSER = new com.google.protobuf.AbstractParser<TopicInputMappingList>() {
      @java.lang.Override
      public TopicInputMappingList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicInputMappingList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicInputMappingList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicInputMappingList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.IoMappings.TopicInputMappingList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface TopicOutputMappingOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.TopicOutputMapping)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string output_name = 1;</code>
     */
    java.lang.String getOutputName();
    /**
     * <code>string output_name = 1;</code>
     */
    com.google.protobuf.ByteString
        getOutputNameBytes();

    /**
     * <code>string topic = 2;</code>
     */
    java.lang.String getTopic();
    /**
     * <code>string topic = 2;</code>
     */
    com.google.protobuf.ByteString
        getTopicBytes();

    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
     */
    boolean hasTopicDemux();
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
     */
    ubii.devices.TopicDemuxOuterClass.TopicDemux getTopicDemux();
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
     */
    ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder getTopicDemuxOrBuilder();

    public ubii.sessions.IoMappings.TopicOutputMapping.TopicDestinationCase getTopicDestinationCase();
  }
  /**
   * Protobuf type {@code ubii.sessions.TopicOutputMapping}
   */
  public  static final class TopicOutputMapping extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.TopicOutputMapping)
      TopicOutputMappingOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicOutputMapping.newBuilder() to construct.
    private TopicOutputMapping(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicOutputMapping() {
      outputName_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicOutputMapping(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              outputName_ = s;
              break;
            }
            case 18: {
              java.lang.String s = input.readStringRequireUtf8();
              topicDestinationCase_ = 2;
              topicDestination_ = s;
              break;
            }
            case 26: {
              ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder subBuilder = null;
              if (topicDestinationCase_ == 3) {
                subBuilder = ((ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_).toBuilder();
              }
              topicDestination_ =
                  input.readMessage(ubii.devices.TopicDemuxOuterClass.TopicDemux.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_);
                topicDestination_ = subBuilder.buildPartial();
              }
              topicDestinationCase_ = 3;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMapping_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMapping_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.IoMappings.TopicOutputMapping.class, ubii.sessions.IoMappings.TopicOutputMapping.Builder.class);
    }

    private int topicDestinationCase_ = 0;
    private java.lang.Object topicDestination_;
    public enum TopicDestinationCase
        implements com.google.protobuf.Internal.EnumLite {
      TOPIC(2),
      TOPIC_DEMUX(3),
      TOPICDESTINATION_NOT_SET(0);
      private final int value;
      private TopicDestinationCase(int value) {
        this.value = value;
      }
      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static TopicDestinationCase valueOf(int value) {
        return forNumber(value);
      }

      public static TopicDestinationCase forNumber(int value) {
        switch (value) {
          case 2: return TOPIC;
          case 3: return TOPIC_DEMUX;
          case 0: return TOPICDESTINATION_NOT_SET;
          default: return null;
        }
      }
      public int getNumber() {
        return this.value;
      }
    };

    public TopicDestinationCase
    getTopicDestinationCase() {
      return TopicDestinationCase.forNumber(
          topicDestinationCase_);
    }

    public static final int OUTPUT_NAME_FIELD_NUMBER = 1;
    private volatile java.lang.Object outputName_;
    /**
     * <code>string output_name = 1;</code>
     */
    public java.lang.String getOutputName() {
      java.lang.Object ref = outputName_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        outputName_ = s;
        return s;
      }
    }
    /**
     * <code>string output_name = 1;</code>
     */
    public com.google.protobuf.ByteString
        getOutputNameBytes() {
      java.lang.Object ref = outputName_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        outputName_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int TOPIC_FIELD_NUMBER = 2;
    /**
     * <code>string topic = 2;</code>
     */
    public java.lang.String getTopic() {
      java.lang.Object ref = "";
      if (topicDestinationCase_ == 2) {
        ref = topicDestination_;
      }
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        if (topicDestinationCase_ == 2) {
          topicDestination_ = s;
        }
        return s;
      }
    }
    /**
     * <code>string topic = 2;</code>
     */
    public com.google.protobuf.ByteString
        getTopicBytes() {
      java.lang.Object ref = "";
      if (topicDestinationCase_ == 2) {
        ref = topicDestination_;
      }
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        if (topicDestinationCase_ == 2) {
          topicDestination_ = b;
        }
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int TOPIC_DEMUX_FIELD_NUMBER = 3;
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
     */
    public boolean hasTopicDemux() {
      return topicDestinationCase_ == 3;
    }
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
     */
    public ubii.devices.TopicDemuxOuterClass.TopicDemux getTopicDemux() {
      if (topicDestinationCase_ == 3) {
         return (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_;
      }
      return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
     */
    public ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder getTopicDemuxOrBuilder() {
      if (topicDestinationCase_ == 3) {
         return (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_;
      }
      return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getOutputNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, outputName_);
      }
      if (topicDestinationCase_ == 2) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 2, topicDestination_);
      }
      if (topicDestinationCase_ == 3) {
        output.writeMessage(3, (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getOutputNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, outputName_);
      }
      if (topicDestinationCase_ == 2) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(2, topicDestination_);
      }
      if (topicDestinationCase_ == 3) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.IoMappings.TopicOutputMapping)) {
        return super.equals(obj);
      }
      ubii.sessions.IoMappings.TopicOutputMapping other = (ubii.sessions.IoMappings.TopicOutputMapping) obj;

      boolean result = true;
      result = result && getOutputName()
          .equals(other.getOutputName());
      result = result && getTopicDestinationCase().equals(
          other.getTopicDestinationCase());
      if (!result) return false;
      switch (topicDestinationCase_) {
        case 2:
          result = result && getTopic()
              .equals(other.getTopic());
          break;
        case 3:
          result = result && getTopicDemux()
              .equals(other.getTopicDemux());
          break;
        case 0:
        default:
      }
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + OUTPUT_NAME_FIELD_NUMBER;
      hash = (53 * hash) + getOutputName().hashCode();
      switch (topicDestinationCase_) {
        case 2:
          hash = (37 * hash) + TOPIC_FIELD_NUMBER;
          hash = (53 * hash) + getTopic().hashCode();
          break;
        case 3:
          hash = (37 * hash) + TOPIC_DEMUX_FIELD_NUMBER;
          hash = (53 * hash) + getTopicDemux().hashCode();
          break;
        case 0:
        default:
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicOutputMapping parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.IoMappings.TopicOutputMapping prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.TopicOutputMapping}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.TopicOutputMapping)
        ubii.sessions.IoMappings.TopicOutputMappingOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMapping_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMapping_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.IoMappings.TopicOutputMapping.class, ubii.sessions.IoMappings.TopicOutputMapping.Builder.class);
      }

      // Construct using ubii.sessions.IoMappings.TopicOutputMapping.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        outputName_ = "";

        topicDestinationCase_ = 0;
        topicDestination_ = null;
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMapping_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicOutputMapping getDefaultInstanceForType() {
        return ubii.sessions.IoMappings.TopicOutputMapping.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicOutputMapping build() {
        ubii.sessions.IoMappings.TopicOutputMapping result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicOutputMapping buildPartial() {
        ubii.sessions.IoMappings.TopicOutputMapping result = new ubii.sessions.IoMappings.TopicOutputMapping(this);
        result.outputName_ = outputName_;
        if (topicDestinationCase_ == 2) {
          result.topicDestination_ = topicDestination_;
        }
        if (topicDestinationCase_ == 3) {
          if (topicDemuxBuilder_ == null) {
            result.topicDestination_ = topicDestination_;
          } else {
            result.topicDestination_ = topicDemuxBuilder_.build();
          }
        }
        result.topicDestinationCase_ = topicDestinationCase_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.IoMappings.TopicOutputMapping) {
          return mergeFrom((ubii.sessions.IoMappings.TopicOutputMapping)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.IoMappings.TopicOutputMapping other) {
        if (other == ubii.sessions.IoMappings.TopicOutputMapping.getDefaultInstance()) return this;
        if (!other.getOutputName().isEmpty()) {
          outputName_ = other.outputName_;
          onChanged();
        }
        switch (other.getTopicDestinationCase()) {
          case TOPIC: {
            topicDestinationCase_ = 2;
            topicDestination_ = other.topicDestination_;
            onChanged();
            break;
          }
          case TOPIC_DEMUX: {
            mergeTopicDemux(other.getTopicDemux());
            break;
          }
          case TOPICDESTINATION_NOT_SET: {
            break;
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.IoMappings.TopicOutputMapping parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.IoMappings.TopicOutputMapping) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int topicDestinationCase_ = 0;
      private java.lang.Object topicDestination_;
      public TopicDestinationCase
          getTopicDestinationCase() {
        return TopicDestinationCase.forNumber(
            topicDestinationCase_);
      }

      public Builder clearTopicDestination() {
        topicDestinationCase_ = 0;
        topicDestination_ = null;
        onChanged();
        return this;
      }


      private java.lang.Object outputName_ = "";
      /**
       * <code>string output_name = 1;</code>
       */
      public java.lang.String getOutputName() {
        java.lang.Object ref = outputName_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          outputName_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string output_name = 1;</code>
       */
      public com.google.protobuf.ByteString
          getOutputNameBytes() {
        java.lang.Object ref = outputName_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          outputName_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string output_name = 1;</code>
       */
      public Builder setOutputName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        outputName_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string output_name = 1;</code>
       */
      public Builder clearOutputName() {
        
        outputName_ = getDefaultInstance().getOutputName();
        onChanged();
        return this;
      }
      /**
       * <code>string output_name = 1;</code>
       */
      public Builder setOutputNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        outputName_ = value;
        onChanged();
        return this;
      }

      /**
       * <code>string topic = 2;</code>
       */
      public java.lang.String getTopic() {
        java.lang.Object ref = "";
        if (topicDestinationCase_ == 2) {
          ref = topicDestination_;
        }
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          if (topicDestinationCase_ == 2) {
            topicDestination_ = s;
          }
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string topic = 2;</code>
       */
      public com.google.protobuf.ByteString
          getTopicBytes() {
        java.lang.Object ref = "";
        if (topicDestinationCase_ == 2) {
          ref = topicDestination_;
        }
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          if (topicDestinationCase_ == 2) {
            topicDestination_ = b;
          }
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string topic = 2;</code>
       */
      public Builder setTopic(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  topicDestinationCase_ = 2;
        topicDestination_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string topic = 2;</code>
       */
      public Builder clearTopic() {
        if (topicDestinationCase_ == 2) {
          topicDestinationCase_ = 0;
          topicDestination_ = null;
          onChanged();
        }
        return this;
      }
      /**
       * <code>string topic = 2;</code>
       */
      public Builder setTopicBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        topicDestinationCase_ = 2;
        topicDestination_ = value;
        onChanged();
        return this;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicDemuxOuterClass.TopicDemux, ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder> topicDemuxBuilder_;
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public boolean hasTopicDemux() {
        return topicDestinationCase_ == 3;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemux getTopicDemux() {
        if (topicDemuxBuilder_ == null) {
          if (topicDestinationCase_ == 3) {
            return (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_;
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
        } else {
          if (topicDestinationCase_ == 3) {
            return topicDemuxBuilder_.getMessage();
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public Builder setTopicDemux(ubii.devices.TopicDemuxOuterClass.TopicDemux value) {
        if (topicDemuxBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          topicDestination_ = value;
          onChanged();
        } else {
          topicDemuxBuilder_.setMessage(value);
        }
        topicDestinationCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public Builder setTopicDemux(
          ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder builderForValue) {
        if (topicDemuxBuilder_ == null) {
          topicDestination_ = builderForValue.build();
          onChanged();
        } else {
          topicDemuxBuilder_.setMessage(builderForValue.build());
        }
        topicDestinationCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public Builder mergeTopicDemux(ubii.devices.TopicDemuxOuterClass.TopicDemux value) {
        if (topicDemuxBuilder_ == null) {
          if (topicDestinationCase_ == 3 &&
              topicDestination_ != ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance()) {
            topicDestination_ = ubii.devices.TopicDemuxOuterClass.TopicDemux.newBuilder((ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_)
                .mergeFrom(value).buildPartial();
          } else {
            topicDestination_ = value;
          }
          onChanged();
        } else {
          if (topicDestinationCase_ == 3) {
            topicDemuxBuilder_.mergeFrom(value);
          }
          topicDemuxBuilder_.setMessage(value);
        }
        topicDestinationCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public Builder clearTopicDemux() {
        if (topicDemuxBuilder_ == null) {
          if (topicDestinationCase_ == 3) {
            topicDestinationCase_ = 0;
            topicDestination_ = null;
            onChanged();
          }
        } else {
          if (topicDestinationCase_ == 3) {
            topicDestinationCase_ = 0;
            topicDestination_ = null;
          }
          topicDemuxBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder getTopicDemuxBuilder() {
        return getTopicDemuxFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder getTopicDemuxOrBuilder() {
        if ((topicDestinationCase_ == 3) && (topicDemuxBuilder_ != null)) {
          return topicDemuxBuilder_.getMessageOrBuilder();
        } else {
          if (topicDestinationCase_ == 3) {
            return (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_;
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 3;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicDemuxOuterClass.TopicDemux, ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder> 
          getTopicDemuxFieldBuilder() {
        if (topicDemuxBuilder_ == null) {
          if (!(topicDestinationCase_ == 3)) {
            topicDestination_ = ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
          }
          topicDemuxBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.TopicDemuxOuterClass.TopicDemux, ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder>(
                  (ubii.devices.TopicDemuxOuterClass.TopicDemux) topicDestination_,
                  getParentForChildren(),
                  isClean());
          topicDestination_ = null;
        }
        topicDestinationCase_ = 3;
        onChanged();;
        return topicDemuxBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.TopicOutputMapping)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.TopicOutputMapping)
    private static final ubii.sessions.IoMappings.TopicOutputMapping DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.IoMappings.TopicOutputMapping();
    }

    public static ubii.sessions.IoMappings.TopicOutputMapping getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicOutputMapping>
        PARSER = new com.google.protobuf.AbstractParser<TopicOutputMapping>() {
      @java.lang.Override
      public TopicOutputMapping parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicOutputMapping(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicOutputMapping> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicOutputMapping> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.IoMappings.TopicOutputMapping getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface TopicOutputMappingListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.TopicOutputMappingList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> 
        getElementsList();
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    ubii.sessions.IoMappings.TopicOutputMapping getElements(int index);
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    java.util.List<? extends ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    ubii.sessions.IoMappings.TopicOutputMappingOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.sessions.TopicOutputMappingList}
   */
  public  static final class TopicOutputMappingList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.TopicOutputMappingList)
      TopicOutputMappingListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use TopicOutputMappingList.newBuilder() to construct.
    private TopicOutputMappingList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private TopicOutputMappingList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private TopicOutputMappingList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicOutputMapping>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.sessions.IoMappings.TopicOutputMapping.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMappingList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMappingList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.IoMappings.TopicOutputMappingList.class, ubii.sessions.IoMappings.TopicOutputMappingList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> elements_;
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    public java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    public java.util.List<? extends ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    public ubii.sessions.IoMappings.TopicOutputMapping getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
     */
    public ubii.sessions.IoMappings.TopicOutputMappingOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.IoMappings.TopicOutputMappingList)) {
        return super.equals(obj);
      }
      ubii.sessions.IoMappings.TopicOutputMappingList other = (ubii.sessions.IoMappings.TopicOutputMappingList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.TopicOutputMappingList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.IoMappings.TopicOutputMappingList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.TopicOutputMappingList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.TopicOutputMappingList)
        ubii.sessions.IoMappings.TopicOutputMappingListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMappingList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMappingList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.IoMappings.TopicOutputMappingList.class, ubii.sessions.IoMappings.TopicOutputMappingList.Builder.class);
      }

      // Construct using ubii.sessions.IoMappings.TopicOutputMappingList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_TopicOutputMappingList_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicOutputMappingList getDefaultInstanceForType() {
        return ubii.sessions.IoMappings.TopicOutputMappingList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicOutputMappingList build() {
        ubii.sessions.IoMappings.TopicOutputMappingList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.TopicOutputMappingList buildPartial() {
        ubii.sessions.IoMappings.TopicOutputMappingList result = new ubii.sessions.IoMappings.TopicOutputMappingList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.IoMappings.TopicOutputMappingList) {
          return mergeFrom((ubii.sessions.IoMappings.TopicOutputMappingList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.IoMappings.TopicOutputMappingList other) {
        if (other == ubii.sessions.IoMappings.TopicOutputMappingList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.IoMappings.TopicOutputMappingList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.IoMappings.TopicOutputMappingList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicOutputMapping>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicOutputMapping, ubii.sessions.IoMappings.TopicOutputMapping.Builder, ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.IoMappings.TopicOutputMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.IoMappings.TopicOutputMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder addElements(ubii.sessions.IoMappings.TopicOutputMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.IoMappings.TopicOutputMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder addElements(
          ubii.sessions.IoMappings.TopicOutputMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.IoMappings.TopicOutputMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.sessions.IoMappings.TopicOutputMapping> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMappingOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public java.util.List<? extends ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.sessions.IoMappings.TopicOutputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.sessions.IoMappings.TopicOutputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping elements = 1;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicOutputMapping.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicOutputMapping, ubii.sessions.IoMappings.TopicOutputMapping.Builder, ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.IoMappings.TopicOutputMapping, ubii.sessions.IoMappings.TopicOutputMapping.Builder, ubii.sessions.IoMappings.TopicOutputMappingOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.TopicOutputMappingList)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.TopicOutputMappingList)
    private static final ubii.sessions.IoMappings.TopicOutputMappingList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.IoMappings.TopicOutputMappingList();
    }

    public static ubii.sessions.IoMappings.TopicOutputMappingList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<TopicOutputMappingList>
        PARSER = new com.google.protobuf.AbstractParser<TopicOutputMappingList>() {
      @java.lang.Override
      public TopicOutputMappingList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new TopicOutputMappingList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<TopicOutputMappingList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<TopicOutputMappingList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.IoMappings.TopicOutputMappingList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface IOMappingOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.IOMapping)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>string processing_module_id = 1;</code>
     */
    java.lang.String getProcessingModuleId();
    /**
     * <code>string processing_module_id = 1;</code>
     */
    com.google.protobuf.ByteString
        getProcessingModuleIdBytes();

    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    java.util.List<ubii.sessions.IoMappings.TopicInputMapping> 
        getInputMappingsList();
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    ubii.sessions.IoMappings.TopicInputMapping getInputMappings(int index);
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    int getInputMappingsCount();
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    java.util.List<? extends ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
        getInputMappingsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    ubii.sessions.IoMappings.TopicInputMappingOrBuilder getInputMappingsOrBuilder(
        int index);

    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> 
        getOutputMappingsList();
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    ubii.sessions.IoMappings.TopicOutputMapping getOutputMappings(int index);
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    int getOutputMappingsCount();
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    java.util.List<? extends ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
        getOutputMappingsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    ubii.sessions.IoMappings.TopicOutputMappingOrBuilder getOutputMappingsOrBuilder(
        int index);

    /**
     * <code>string processing_module_name = 4;</code>
     */
    java.lang.String getProcessingModuleName();
    /**
     * <code>string processing_module_name = 4;</code>
     */
    com.google.protobuf.ByteString
        getProcessingModuleNameBytes();
  }
  /**
   * Protobuf type {@code ubii.sessions.IOMapping}
   */
  public  static final class IOMapping extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.IOMapping)
      IOMappingOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use IOMapping.newBuilder() to construct.
    private IOMapping(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private IOMapping() {
      processingModuleId_ = "";
      inputMappings_ = java.util.Collections.emptyList();
      outputMappings_ = java.util.Collections.emptyList();
      processingModuleName_ = "";
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private IOMapping(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              java.lang.String s = input.readStringRequireUtf8();

              processingModuleId_ = s;
              break;
            }
            case 18: {
              if (!((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
                inputMappings_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicInputMapping>();
                mutable_bitField0_ |= 0x00000002;
              }
              inputMappings_.add(
                  input.readMessage(ubii.sessions.IoMappings.TopicInputMapping.parser(), extensionRegistry));
              break;
            }
            case 26: {
              if (!((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
                outputMappings_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicOutputMapping>();
                mutable_bitField0_ |= 0x00000004;
              }
              outputMappings_.add(
                  input.readMessage(ubii.sessions.IoMappings.TopicOutputMapping.parser(), extensionRegistry));
              break;
            }
            case 34: {
              java.lang.String s = input.readStringRequireUtf8();

              processingModuleName_ = s;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000002) == 0x00000002)) {
          inputMappings_ = java.util.Collections.unmodifiableList(inputMappings_);
        }
        if (((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
          outputMappings_ = java.util.Collections.unmodifiableList(outputMappings_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMapping_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMapping_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.IoMappings.IOMapping.class, ubii.sessions.IoMappings.IOMapping.Builder.class);
    }

    private int bitField0_;
    public static final int PROCESSING_MODULE_ID_FIELD_NUMBER = 1;
    private volatile java.lang.Object processingModuleId_;
    /**
     * <code>string processing_module_id = 1;</code>
     */
    public java.lang.String getProcessingModuleId() {
      java.lang.Object ref = processingModuleId_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        processingModuleId_ = s;
        return s;
      }
    }
    /**
     * <code>string processing_module_id = 1;</code>
     */
    public com.google.protobuf.ByteString
        getProcessingModuleIdBytes() {
      java.lang.Object ref = processingModuleId_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        processingModuleId_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    public static final int INPUT_MAPPINGS_FIELD_NUMBER = 2;
    private java.util.List<ubii.sessions.IoMappings.TopicInputMapping> inputMappings_;
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    public java.util.List<ubii.sessions.IoMappings.TopicInputMapping> getInputMappingsList() {
      return inputMappings_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    public java.util.List<? extends ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
        getInputMappingsOrBuilderList() {
      return inputMappings_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    public int getInputMappingsCount() {
      return inputMappings_.size();
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    public ubii.sessions.IoMappings.TopicInputMapping getInputMappings(int index) {
      return inputMappings_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
     */
    public ubii.sessions.IoMappings.TopicInputMappingOrBuilder getInputMappingsOrBuilder(
        int index) {
      return inputMappings_.get(index);
    }

    public static final int OUTPUT_MAPPINGS_FIELD_NUMBER = 3;
    private java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> outputMappings_;
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    public java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> getOutputMappingsList() {
      return outputMappings_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    public java.util.List<? extends ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
        getOutputMappingsOrBuilderList() {
      return outputMappings_;
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    public int getOutputMappingsCount() {
      return outputMappings_.size();
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    public ubii.sessions.IoMappings.TopicOutputMapping getOutputMappings(int index) {
      return outputMappings_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
     */
    public ubii.sessions.IoMappings.TopicOutputMappingOrBuilder getOutputMappingsOrBuilder(
        int index) {
      return outputMappings_.get(index);
    }

    public static final int PROCESSING_MODULE_NAME_FIELD_NUMBER = 4;
    private volatile java.lang.Object processingModuleName_;
    /**
     * <code>string processing_module_name = 4;</code>
     */
    public java.lang.String getProcessingModuleName() {
      java.lang.Object ref = processingModuleName_;
      if (ref instanceof java.lang.String) {
        return (java.lang.String) ref;
      } else {
        com.google.protobuf.ByteString bs = 
            (com.google.protobuf.ByteString) ref;
        java.lang.String s = bs.toStringUtf8();
        processingModuleName_ = s;
        return s;
      }
    }
    /**
     * <code>string processing_module_name = 4;</code>
     */
    public com.google.protobuf.ByteString
        getProcessingModuleNameBytes() {
      java.lang.Object ref = processingModuleName_;
      if (ref instanceof java.lang.String) {
        com.google.protobuf.ByteString b = 
            com.google.protobuf.ByteString.copyFromUtf8(
                (java.lang.String) ref);
        processingModuleName_ = b;
        return b;
      } else {
        return (com.google.protobuf.ByteString) ref;
      }
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (!getProcessingModuleIdBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 1, processingModuleId_);
      }
      for (int i = 0; i < inputMappings_.size(); i++) {
        output.writeMessage(2, inputMappings_.get(i));
      }
      for (int i = 0; i < outputMappings_.size(); i++) {
        output.writeMessage(3, outputMappings_.get(i));
      }
      if (!getProcessingModuleNameBytes().isEmpty()) {
        com.google.protobuf.GeneratedMessageV3.writeString(output, 4, processingModuleName_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (!getProcessingModuleIdBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(1, processingModuleId_);
      }
      for (int i = 0; i < inputMappings_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, inputMappings_.get(i));
      }
      for (int i = 0; i < outputMappings_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, outputMappings_.get(i));
      }
      if (!getProcessingModuleNameBytes().isEmpty()) {
        size += com.google.protobuf.GeneratedMessageV3.computeStringSize(4, processingModuleName_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.IoMappings.IOMapping)) {
        return super.equals(obj);
      }
      ubii.sessions.IoMappings.IOMapping other = (ubii.sessions.IoMappings.IOMapping) obj;

      boolean result = true;
      result = result && getProcessingModuleId()
          .equals(other.getProcessingModuleId());
      result = result && getInputMappingsList()
          .equals(other.getInputMappingsList());
      result = result && getOutputMappingsList()
          .equals(other.getOutputMappingsList());
      result = result && getProcessingModuleName()
          .equals(other.getProcessingModuleName());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      hash = (37 * hash) + PROCESSING_MODULE_ID_FIELD_NUMBER;
      hash = (53 * hash) + getProcessingModuleId().hashCode();
      if (getInputMappingsCount() > 0) {
        hash = (37 * hash) + INPUT_MAPPINGS_FIELD_NUMBER;
        hash = (53 * hash) + getInputMappingsList().hashCode();
      }
      if (getOutputMappingsCount() > 0) {
        hash = (37 * hash) + OUTPUT_MAPPINGS_FIELD_NUMBER;
        hash = (53 * hash) + getOutputMappingsList().hashCode();
      }
      hash = (37 * hash) + PROCESSING_MODULE_NAME_FIELD_NUMBER;
      hash = (53 * hash) + getProcessingModuleName().hashCode();
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMapping parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.IOMapping parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.IOMapping parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.IoMappings.IOMapping prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.IOMapping}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.IOMapping)
        ubii.sessions.IoMappings.IOMappingOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMapping_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMapping_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.IoMappings.IOMapping.class, ubii.sessions.IoMappings.IOMapping.Builder.class);
      }

      // Construct using ubii.sessions.IoMappings.IOMapping.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getInputMappingsFieldBuilder();
          getOutputMappingsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        processingModuleId_ = "";

        if (inputMappingsBuilder_ == null) {
          inputMappings_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000002);
        } else {
          inputMappingsBuilder_.clear();
        }
        if (outputMappingsBuilder_ == null) {
          outputMappings_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000004);
        } else {
          outputMappingsBuilder_.clear();
        }
        processingModuleName_ = "";

        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMapping_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.IOMapping getDefaultInstanceForType() {
        return ubii.sessions.IoMappings.IOMapping.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.IOMapping build() {
        ubii.sessions.IoMappings.IOMapping result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.IOMapping buildPartial() {
        ubii.sessions.IoMappings.IOMapping result = new ubii.sessions.IoMappings.IOMapping(this);
        int from_bitField0_ = bitField0_;
        int to_bitField0_ = 0;
        result.processingModuleId_ = processingModuleId_;
        if (inputMappingsBuilder_ == null) {
          if (((bitField0_ & 0x00000002) == 0x00000002)) {
            inputMappings_ = java.util.Collections.unmodifiableList(inputMappings_);
            bitField0_ = (bitField0_ & ~0x00000002);
          }
          result.inputMappings_ = inputMappings_;
        } else {
          result.inputMappings_ = inputMappingsBuilder_.build();
        }
        if (outputMappingsBuilder_ == null) {
          if (((bitField0_ & 0x00000004) == 0x00000004)) {
            outputMappings_ = java.util.Collections.unmodifiableList(outputMappings_);
            bitField0_ = (bitField0_ & ~0x00000004);
          }
          result.outputMappings_ = outputMappings_;
        } else {
          result.outputMappings_ = outputMappingsBuilder_.build();
        }
        result.processingModuleName_ = processingModuleName_;
        result.bitField0_ = to_bitField0_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.IoMappings.IOMapping) {
          return mergeFrom((ubii.sessions.IoMappings.IOMapping)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.IoMappings.IOMapping other) {
        if (other == ubii.sessions.IoMappings.IOMapping.getDefaultInstance()) return this;
        if (!other.getProcessingModuleId().isEmpty()) {
          processingModuleId_ = other.processingModuleId_;
          onChanged();
        }
        if (inputMappingsBuilder_ == null) {
          if (!other.inputMappings_.isEmpty()) {
            if (inputMappings_.isEmpty()) {
              inputMappings_ = other.inputMappings_;
              bitField0_ = (bitField0_ & ~0x00000002);
            } else {
              ensureInputMappingsIsMutable();
              inputMappings_.addAll(other.inputMappings_);
            }
            onChanged();
          }
        } else {
          if (!other.inputMappings_.isEmpty()) {
            if (inputMappingsBuilder_.isEmpty()) {
              inputMappingsBuilder_.dispose();
              inputMappingsBuilder_ = null;
              inputMappings_ = other.inputMappings_;
              bitField0_ = (bitField0_ & ~0x00000002);
              inputMappingsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getInputMappingsFieldBuilder() : null;
            } else {
              inputMappingsBuilder_.addAllMessages(other.inputMappings_);
            }
          }
        }
        if (outputMappingsBuilder_ == null) {
          if (!other.outputMappings_.isEmpty()) {
            if (outputMappings_.isEmpty()) {
              outputMappings_ = other.outputMappings_;
              bitField0_ = (bitField0_ & ~0x00000004);
            } else {
              ensureOutputMappingsIsMutable();
              outputMappings_.addAll(other.outputMappings_);
            }
            onChanged();
          }
        } else {
          if (!other.outputMappings_.isEmpty()) {
            if (outputMappingsBuilder_.isEmpty()) {
              outputMappingsBuilder_.dispose();
              outputMappingsBuilder_ = null;
              outputMappings_ = other.outputMappings_;
              bitField0_ = (bitField0_ & ~0x00000004);
              outputMappingsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getOutputMappingsFieldBuilder() : null;
            } else {
              outputMappingsBuilder_.addAllMessages(other.outputMappings_);
            }
          }
        }
        if (!other.getProcessingModuleName().isEmpty()) {
          processingModuleName_ = other.processingModuleName_;
          onChanged();
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.IoMappings.IOMapping parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.IoMappings.IOMapping) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.lang.Object processingModuleId_ = "";
      /**
       * <code>string processing_module_id = 1;</code>
       */
      public java.lang.String getProcessingModuleId() {
        java.lang.Object ref = processingModuleId_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          processingModuleId_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string processing_module_id = 1;</code>
       */
      public com.google.protobuf.ByteString
          getProcessingModuleIdBytes() {
        java.lang.Object ref = processingModuleId_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          processingModuleId_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string processing_module_id = 1;</code>
       */
      public Builder setProcessingModuleId(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        processingModuleId_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string processing_module_id = 1;</code>
       */
      public Builder clearProcessingModuleId() {
        
        processingModuleId_ = getDefaultInstance().getProcessingModuleId();
        onChanged();
        return this;
      }
      /**
       * <code>string processing_module_id = 1;</code>
       */
      public Builder setProcessingModuleIdBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        processingModuleId_ = value;
        onChanged();
        return this;
      }

      private java.util.List<ubii.sessions.IoMappings.TopicInputMapping> inputMappings_ =
        java.util.Collections.emptyList();
      private void ensureInputMappingsIsMutable() {
        if (!((bitField0_ & 0x00000002) == 0x00000002)) {
          inputMappings_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicInputMapping>(inputMappings_);
          bitField0_ |= 0x00000002;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicInputMapping, ubii.sessions.IoMappings.TopicInputMapping.Builder, ubii.sessions.IoMappings.TopicInputMappingOrBuilder> inputMappingsBuilder_;

      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicInputMapping> getInputMappingsList() {
        if (inputMappingsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(inputMappings_);
        } else {
          return inputMappingsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public int getInputMappingsCount() {
        if (inputMappingsBuilder_ == null) {
          return inputMappings_.size();
        } else {
          return inputMappingsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping getInputMappings(int index) {
        if (inputMappingsBuilder_ == null) {
          return inputMappings_.get(index);
        } else {
          return inputMappingsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder setInputMappings(
          int index, ubii.sessions.IoMappings.TopicInputMapping value) {
        if (inputMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureInputMappingsIsMutable();
          inputMappings_.set(index, value);
          onChanged();
        } else {
          inputMappingsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder setInputMappings(
          int index, ubii.sessions.IoMappings.TopicInputMapping.Builder builderForValue) {
        if (inputMappingsBuilder_ == null) {
          ensureInputMappingsIsMutable();
          inputMappings_.set(index, builderForValue.build());
          onChanged();
        } else {
          inputMappingsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder addInputMappings(ubii.sessions.IoMappings.TopicInputMapping value) {
        if (inputMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureInputMappingsIsMutable();
          inputMappings_.add(value);
          onChanged();
        } else {
          inputMappingsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder addInputMappings(
          int index, ubii.sessions.IoMappings.TopicInputMapping value) {
        if (inputMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureInputMappingsIsMutable();
          inputMappings_.add(index, value);
          onChanged();
        } else {
          inputMappingsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder addInputMappings(
          ubii.sessions.IoMappings.TopicInputMapping.Builder builderForValue) {
        if (inputMappingsBuilder_ == null) {
          ensureInputMappingsIsMutable();
          inputMappings_.add(builderForValue.build());
          onChanged();
        } else {
          inputMappingsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder addInputMappings(
          int index, ubii.sessions.IoMappings.TopicInputMapping.Builder builderForValue) {
        if (inputMappingsBuilder_ == null) {
          ensureInputMappingsIsMutable();
          inputMappings_.add(index, builderForValue.build());
          onChanged();
        } else {
          inputMappingsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder addAllInputMappings(
          java.lang.Iterable<? extends ubii.sessions.IoMappings.TopicInputMapping> values) {
        if (inputMappingsBuilder_ == null) {
          ensureInputMappingsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, inputMappings_);
          onChanged();
        } else {
          inputMappingsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder clearInputMappings() {
        if (inputMappingsBuilder_ == null) {
          inputMappings_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000002);
          onChanged();
        } else {
          inputMappingsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public Builder removeInputMappings(int index) {
        if (inputMappingsBuilder_ == null) {
          ensureInputMappingsIsMutable();
          inputMappings_.remove(index);
          onChanged();
        } else {
          inputMappingsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping.Builder getInputMappingsBuilder(
          int index) {
        return getInputMappingsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMappingOrBuilder getInputMappingsOrBuilder(
          int index) {
        if (inputMappingsBuilder_ == null) {
          return inputMappings_.get(index);  } else {
          return inputMappingsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public java.util.List<? extends ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
           getInputMappingsOrBuilderList() {
        if (inputMappingsBuilder_ != null) {
          return inputMappingsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(inputMappings_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping.Builder addInputMappingsBuilder() {
        return getInputMappingsFieldBuilder().addBuilder(
            ubii.sessions.IoMappings.TopicInputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public ubii.sessions.IoMappings.TopicInputMapping.Builder addInputMappingsBuilder(
          int index) {
        return getInputMappingsFieldBuilder().addBuilder(
            index, ubii.sessions.IoMappings.TopicInputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicInputMapping input_mappings = 2;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicInputMapping.Builder> 
           getInputMappingsBuilderList() {
        return getInputMappingsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicInputMapping, ubii.sessions.IoMappings.TopicInputMapping.Builder, ubii.sessions.IoMappings.TopicInputMappingOrBuilder> 
          getInputMappingsFieldBuilder() {
        if (inputMappingsBuilder_ == null) {
          inputMappingsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.IoMappings.TopicInputMapping, ubii.sessions.IoMappings.TopicInputMapping.Builder, ubii.sessions.IoMappings.TopicInputMappingOrBuilder>(
                  inputMappings_,
                  ((bitField0_ & 0x00000002) == 0x00000002),
                  getParentForChildren(),
                  isClean());
          inputMappings_ = null;
        }
        return inputMappingsBuilder_;
      }

      private java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> outputMappings_ =
        java.util.Collections.emptyList();
      private void ensureOutputMappingsIsMutable() {
        if (!((bitField0_ & 0x00000004) == 0x00000004)) {
          outputMappings_ = new java.util.ArrayList<ubii.sessions.IoMappings.TopicOutputMapping>(outputMappings_);
          bitField0_ |= 0x00000004;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicOutputMapping, ubii.sessions.IoMappings.TopicOutputMapping.Builder, ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> outputMappingsBuilder_;

      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicOutputMapping> getOutputMappingsList() {
        if (outputMappingsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(outputMappings_);
        } else {
          return outputMappingsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public int getOutputMappingsCount() {
        if (outputMappingsBuilder_ == null) {
          return outputMappings_.size();
        } else {
          return outputMappingsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping getOutputMappings(int index) {
        if (outputMappingsBuilder_ == null) {
          return outputMappings_.get(index);
        } else {
          return outputMappingsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder setOutputMappings(
          int index, ubii.sessions.IoMappings.TopicOutputMapping value) {
        if (outputMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureOutputMappingsIsMutable();
          outputMappings_.set(index, value);
          onChanged();
        } else {
          outputMappingsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder setOutputMappings(
          int index, ubii.sessions.IoMappings.TopicOutputMapping.Builder builderForValue) {
        if (outputMappingsBuilder_ == null) {
          ensureOutputMappingsIsMutable();
          outputMappings_.set(index, builderForValue.build());
          onChanged();
        } else {
          outputMappingsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder addOutputMappings(ubii.sessions.IoMappings.TopicOutputMapping value) {
        if (outputMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureOutputMappingsIsMutable();
          outputMappings_.add(value);
          onChanged();
        } else {
          outputMappingsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder addOutputMappings(
          int index, ubii.sessions.IoMappings.TopicOutputMapping value) {
        if (outputMappingsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureOutputMappingsIsMutable();
          outputMappings_.add(index, value);
          onChanged();
        } else {
          outputMappingsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder addOutputMappings(
          ubii.sessions.IoMappings.TopicOutputMapping.Builder builderForValue) {
        if (outputMappingsBuilder_ == null) {
          ensureOutputMappingsIsMutable();
          outputMappings_.add(builderForValue.build());
          onChanged();
        } else {
          outputMappingsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder addOutputMappings(
          int index, ubii.sessions.IoMappings.TopicOutputMapping.Builder builderForValue) {
        if (outputMappingsBuilder_ == null) {
          ensureOutputMappingsIsMutable();
          outputMappings_.add(index, builderForValue.build());
          onChanged();
        } else {
          outputMappingsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder addAllOutputMappings(
          java.lang.Iterable<? extends ubii.sessions.IoMappings.TopicOutputMapping> values) {
        if (outputMappingsBuilder_ == null) {
          ensureOutputMappingsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, outputMappings_);
          onChanged();
        } else {
          outputMappingsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder clearOutputMappings() {
        if (outputMappingsBuilder_ == null) {
          outputMappings_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000004);
          onChanged();
        } else {
          outputMappingsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public Builder removeOutputMappings(int index) {
        if (outputMappingsBuilder_ == null) {
          ensureOutputMappingsIsMutable();
          outputMappings_.remove(index);
          onChanged();
        } else {
          outputMappingsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping.Builder getOutputMappingsBuilder(
          int index) {
        return getOutputMappingsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMappingOrBuilder getOutputMappingsOrBuilder(
          int index) {
        if (outputMappingsBuilder_ == null) {
          return outputMappings_.get(index);  } else {
          return outputMappingsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public java.util.List<? extends ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
           getOutputMappingsOrBuilderList() {
        if (outputMappingsBuilder_ != null) {
          return outputMappingsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(outputMappings_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping.Builder addOutputMappingsBuilder() {
        return getOutputMappingsFieldBuilder().addBuilder(
            ubii.sessions.IoMappings.TopicOutputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public ubii.sessions.IoMappings.TopicOutputMapping.Builder addOutputMappingsBuilder(
          int index) {
        return getOutputMappingsFieldBuilder().addBuilder(
            index, ubii.sessions.IoMappings.TopicOutputMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.TopicOutputMapping output_mappings = 3;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.TopicOutputMapping.Builder> 
           getOutputMappingsBuilderList() {
        return getOutputMappingsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.TopicOutputMapping, ubii.sessions.IoMappings.TopicOutputMapping.Builder, ubii.sessions.IoMappings.TopicOutputMappingOrBuilder> 
          getOutputMappingsFieldBuilder() {
        if (outputMappingsBuilder_ == null) {
          outputMappingsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.IoMappings.TopicOutputMapping, ubii.sessions.IoMappings.TopicOutputMapping.Builder, ubii.sessions.IoMappings.TopicOutputMappingOrBuilder>(
                  outputMappings_,
                  ((bitField0_ & 0x00000004) == 0x00000004),
                  getParentForChildren(),
                  isClean());
          outputMappings_ = null;
        }
        return outputMappingsBuilder_;
      }

      private java.lang.Object processingModuleName_ = "";
      /**
       * <code>string processing_module_name = 4;</code>
       */
      public java.lang.String getProcessingModuleName() {
        java.lang.Object ref = processingModuleName_;
        if (!(ref instanceof java.lang.String)) {
          com.google.protobuf.ByteString bs =
              (com.google.protobuf.ByteString) ref;
          java.lang.String s = bs.toStringUtf8();
          processingModuleName_ = s;
          return s;
        } else {
          return (java.lang.String) ref;
        }
      }
      /**
       * <code>string processing_module_name = 4;</code>
       */
      public com.google.protobuf.ByteString
          getProcessingModuleNameBytes() {
        java.lang.Object ref = processingModuleName_;
        if (ref instanceof String) {
          com.google.protobuf.ByteString b = 
              com.google.protobuf.ByteString.copyFromUtf8(
                  (java.lang.String) ref);
          processingModuleName_ = b;
          return b;
        } else {
          return (com.google.protobuf.ByteString) ref;
        }
      }
      /**
       * <code>string processing_module_name = 4;</code>
       */
      public Builder setProcessingModuleName(
          java.lang.String value) {
        if (value == null) {
    throw new NullPointerException();
  }
  
        processingModuleName_ = value;
        onChanged();
        return this;
      }
      /**
       * <code>string processing_module_name = 4;</code>
       */
      public Builder clearProcessingModuleName() {
        
        processingModuleName_ = getDefaultInstance().getProcessingModuleName();
        onChanged();
        return this;
      }
      /**
       * <code>string processing_module_name = 4;</code>
       */
      public Builder setProcessingModuleNameBytes(
          com.google.protobuf.ByteString value) {
        if (value == null) {
    throw new NullPointerException();
  }
  checkByteStringIsUtf8(value);
        
        processingModuleName_ = value;
        onChanged();
        return this;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.IOMapping)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.IOMapping)
    private static final ubii.sessions.IoMappings.IOMapping DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.IoMappings.IOMapping();
    }

    public static ubii.sessions.IoMappings.IOMapping getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<IOMapping>
        PARSER = new com.google.protobuf.AbstractParser<IOMapping>() {
      @java.lang.Override
      public IOMapping parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new IOMapping(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<IOMapping> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<IOMapping> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.IoMappings.IOMapping getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  public interface IOMappingListOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.sessions.IOMappingList)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    java.util.List<ubii.sessions.IoMappings.IOMapping> 
        getElementsList();
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    ubii.sessions.IoMappings.IOMapping getElements(int index);
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    int getElementsCount();
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    java.util.List<? extends ubii.sessions.IoMappings.IOMappingOrBuilder> 
        getElementsOrBuilderList();
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    ubii.sessions.IoMappings.IOMappingOrBuilder getElementsOrBuilder(
        int index);
  }
  /**
   * Protobuf type {@code ubii.sessions.IOMappingList}
   */
  public  static final class IOMappingList extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.sessions.IOMappingList)
      IOMappingListOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use IOMappingList.newBuilder() to construct.
    private IOMappingList(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private IOMappingList() {
      elements_ = java.util.Collections.emptyList();
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private IOMappingList(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              if (!((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
                elements_ = new java.util.ArrayList<ubii.sessions.IoMappings.IOMapping>();
                mutable_bitField0_ |= 0x00000001;
              }
              elements_.add(
                  input.readMessage(ubii.sessions.IoMappings.IOMapping.parser(), extensionRegistry));
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        if (((mutable_bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = java.util.Collections.unmodifiableList(elements_);
        }
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMappingList_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMappingList_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.sessions.IoMappings.IOMappingList.class, ubii.sessions.IoMappings.IOMappingList.Builder.class);
    }

    public static final int ELEMENTS_FIELD_NUMBER = 1;
    private java.util.List<ubii.sessions.IoMappings.IOMapping> elements_;
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    public java.util.List<ubii.sessions.IoMappings.IOMapping> getElementsList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    public java.util.List<? extends ubii.sessions.IoMappings.IOMappingOrBuilder> 
        getElementsOrBuilderList() {
      return elements_;
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    public int getElementsCount() {
      return elements_.size();
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    public ubii.sessions.IoMappings.IOMapping getElements(int index) {
      return elements_.get(index);
    }
    /**
     * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
     */
    public ubii.sessions.IoMappings.IOMappingOrBuilder getElementsOrBuilder(
        int index) {
      return elements_.get(index);
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      for (int i = 0; i < elements_.size(); i++) {
        output.writeMessage(1, elements_.get(i));
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      for (int i = 0; i < elements_.size(); i++) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, elements_.get(i));
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.sessions.IoMappings.IOMappingList)) {
        return super.equals(obj);
      }
      ubii.sessions.IoMappings.IOMappingList other = (ubii.sessions.IoMappings.IOMappingList) obj;

      boolean result = true;
      result = result && getElementsList()
          .equals(other.getElementsList());
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      if (getElementsCount() > 0) {
        hash = (37 * hash) + ELEMENTS_FIELD_NUMBER;
        hash = (53 * hash) + getElementsList().hashCode();
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.sessions.IoMappings.IOMappingList parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.sessions.IoMappings.IOMappingList prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.sessions.IOMappingList}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.sessions.IOMappingList)
        ubii.sessions.IoMappings.IOMappingListOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMappingList_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMappingList_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.sessions.IoMappings.IOMappingList.class, ubii.sessions.IoMappings.IOMappingList.Builder.class);
      }

      // Construct using ubii.sessions.IoMappings.IOMappingList.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
          getElementsFieldBuilder();
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.sessions.IoMappings.internal_static_ubii_sessions_IOMappingList_descriptor;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.IOMappingList getDefaultInstanceForType() {
        return ubii.sessions.IoMappings.IOMappingList.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.IOMappingList build() {
        ubii.sessions.IoMappings.IOMappingList result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.sessions.IoMappings.IOMappingList buildPartial() {
        ubii.sessions.IoMappings.IOMappingList result = new ubii.sessions.IoMappings.IOMappingList(this);
        int from_bitField0_ = bitField0_;
        if (elementsBuilder_ == null) {
          if (((bitField0_ & 0x00000001) == 0x00000001)) {
            elements_ = java.util.Collections.unmodifiableList(elements_);
            bitField0_ = (bitField0_ & ~0x00000001);
          }
          result.elements_ = elements_;
        } else {
          result.elements_ = elementsBuilder_.build();
        }
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.sessions.IoMappings.IOMappingList) {
          return mergeFrom((ubii.sessions.IoMappings.IOMappingList)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.sessions.IoMappings.IOMappingList other) {
        if (other == ubii.sessions.IoMappings.IOMappingList.getDefaultInstance()) return this;
        if (elementsBuilder_ == null) {
          if (!other.elements_.isEmpty()) {
            if (elements_.isEmpty()) {
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
            } else {
              ensureElementsIsMutable();
              elements_.addAll(other.elements_);
            }
            onChanged();
          }
        } else {
          if (!other.elements_.isEmpty()) {
            if (elementsBuilder_.isEmpty()) {
              elementsBuilder_.dispose();
              elementsBuilder_ = null;
              elements_ = other.elements_;
              bitField0_ = (bitField0_ & ~0x00000001);
              elementsBuilder_ = 
                com.google.protobuf.GeneratedMessageV3.alwaysUseFieldBuilders ?
                   getElementsFieldBuilder() : null;
            } else {
              elementsBuilder_.addAllMessages(other.elements_);
            }
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.sessions.IoMappings.IOMappingList parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.sessions.IoMappings.IOMappingList) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int bitField0_;

      private java.util.List<ubii.sessions.IoMappings.IOMapping> elements_ =
        java.util.Collections.emptyList();
      private void ensureElementsIsMutable() {
        if (!((bitField0_ & 0x00000001) == 0x00000001)) {
          elements_ = new java.util.ArrayList<ubii.sessions.IoMappings.IOMapping>(elements_);
          bitField0_ |= 0x00000001;
         }
      }

      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.IOMapping, ubii.sessions.IoMappings.IOMapping.Builder, ubii.sessions.IoMappings.IOMappingOrBuilder> elementsBuilder_;

      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.IOMapping> getElementsList() {
        if (elementsBuilder_ == null) {
          return java.util.Collections.unmodifiableList(elements_);
        } else {
          return elementsBuilder_.getMessageList();
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public int getElementsCount() {
        if (elementsBuilder_ == null) {
          return elements_.size();
        } else {
          return elementsBuilder_.getCount();
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.IOMapping getElements(int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);
        } else {
          return elementsBuilder_.getMessage(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.IoMappings.IOMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.set(index, value);
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder setElements(
          int index, ubii.sessions.IoMappings.IOMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.set(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.setMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder addElements(ubii.sessions.IoMappings.IOMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.IoMappings.IOMapping value) {
        if (elementsBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          ensureElementsIsMutable();
          elements_.add(index, value);
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, value);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder addElements(
          ubii.sessions.IoMappings.IOMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder addElements(
          int index, ubii.sessions.IoMappings.IOMapping.Builder builderForValue) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.add(index, builderForValue.build());
          onChanged();
        } else {
          elementsBuilder_.addMessage(index, builderForValue.build());
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder addAllElements(
          java.lang.Iterable<? extends ubii.sessions.IoMappings.IOMapping> values) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          com.google.protobuf.AbstractMessageLite.Builder.addAll(
              values, elements_);
          onChanged();
        } else {
          elementsBuilder_.addAllMessages(values);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder clearElements() {
        if (elementsBuilder_ == null) {
          elements_ = java.util.Collections.emptyList();
          bitField0_ = (bitField0_ & ~0x00000001);
          onChanged();
        } else {
          elementsBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public Builder removeElements(int index) {
        if (elementsBuilder_ == null) {
          ensureElementsIsMutable();
          elements_.remove(index);
          onChanged();
        } else {
          elementsBuilder_.remove(index);
        }
        return this;
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.IOMapping.Builder getElementsBuilder(
          int index) {
        return getElementsFieldBuilder().getBuilder(index);
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.IOMappingOrBuilder getElementsOrBuilder(
          int index) {
        if (elementsBuilder_ == null) {
          return elements_.get(index);  } else {
          return elementsBuilder_.getMessageOrBuilder(index);
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public java.util.List<? extends ubii.sessions.IoMappings.IOMappingOrBuilder> 
           getElementsOrBuilderList() {
        if (elementsBuilder_ != null) {
          return elementsBuilder_.getMessageOrBuilderList();
        } else {
          return java.util.Collections.unmodifiableList(elements_);
        }
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.IOMapping.Builder addElementsBuilder() {
        return getElementsFieldBuilder().addBuilder(
            ubii.sessions.IoMappings.IOMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public ubii.sessions.IoMappings.IOMapping.Builder addElementsBuilder(
          int index) {
        return getElementsFieldBuilder().addBuilder(
            index, ubii.sessions.IoMappings.IOMapping.getDefaultInstance());
      }
      /**
       * <code>repeated .ubii.sessions.IOMapping elements = 1;</code>
       */
      public java.util.List<ubii.sessions.IoMappings.IOMapping.Builder> 
           getElementsBuilderList() {
        return getElementsFieldBuilder().getBuilderList();
      }
      private com.google.protobuf.RepeatedFieldBuilderV3<
          ubii.sessions.IoMappings.IOMapping, ubii.sessions.IoMappings.IOMapping.Builder, ubii.sessions.IoMappings.IOMappingOrBuilder> 
          getElementsFieldBuilder() {
        if (elementsBuilder_ == null) {
          elementsBuilder_ = new com.google.protobuf.RepeatedFieldBuilderV3<
              ubii.sessions.IoMappings.IOMapping, ubii.sessions.IoMappings.IOMapping.Builder, ubii.sessions.IoMappings.IOMappingOrBuilder>(
                  elements_,
                  ((bitField0_ & 0x00000001) == 0x00000001),
                  getParentForChildren(),
                  isClean());
          elements_ = null;
        }
        return elementsBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.sessions.IOMappingList)
    }

    // @@protoc_insertion_point(class_scope:ubii.sessions.IOMappingList)
    private static final ubii.sessions.IoMappings.IOMappingList DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.sessions.IoMappings.IOMappingList();
    }

    public static ubii.sessions.IoMappings.IOMappingList getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<IOMappingList>
        PARSER = new com.google.protobuf.AbstractParser<IOMappingList>() {
      @java.lang.Override
      public IOMappingList parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new IOMappingList(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<IOMappingList> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<IOMappingList> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.sessions.IoMappings.IOMappingList getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_TopicInputMapping_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_TopicInputMapping_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_TopicInputMappingList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_TopicInputMappingList_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_TopicOutputMapping_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_TopicOutputMapping_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_TopicOutputMappingList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_TopicOutputMappingList_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_IOMapping_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_IOMapping_fieldAccessorTable;
  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_sessions_IOMappingList_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_sessions_IOMappingList_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n\037proto/sessions/ioMappings.proto\022\rubii." +
      "sessions\032\034proto/devices/topicMux.proto\032\036" +
      "proto/devices/topicDemux.proto\"u\n\021TopicI" +
      "nputMapping\022\022\n\ninput_name\030\001 \001(\t\022\017\n\005topic" +
      "\030\002 \001(\tH\000\022+\n\ttopic_mux\030\003 \001(\0132\026.ubii.devic" +
      "es.TopicMuxH\000B\016\n\014topic_source\"K\n\025TopicIn" +
      "putMappingList\0222\n\010elements\030\001 \003(\0132 .ubii." +
      "sessions.TopicInputMapping\"\200\001\n\022TopicOutp" +
      "utMapping\022\023\n\013output_name\030\001 \001(\t\022\017\n\005topic\030" +
      "\002 \001(\tH\000\022/\n\013topic_demux\030\003 \001(\0132\030.ubii.devi" +
      "ces.TopicDemuxH\000B\023\n\021topic_destination\"M\n" +
      "\026TopicOutputMappingList\0223\n\010elements\030\001 \003(" +
      "\0132!.ubii.sessions.TopicOutputMapping\"\277\001\n" +
      "\tIOMapping\022\034\n\024processing_module_id\030\001 \001(\t" +
      "\0228\n\016input_mappings\030\002 \003(\0132 .ubii.sessions" +
      ".TopicInputMapping\022:\n\017output_mappings\030\003 " +
      "\003(\0132!.ubii.sessions.TopicOutputMapping\022\036" +
      "\n\026processing_module_name\030\004 \001(\t\";\n\rIOMapp" +
      "ingList\022*\n\010elements\030\001 \003(\0132\030.ubii.session" +
      "s.IOMappingb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.devices.TopicMuxOuterClass.getDescriptor(),
          ubii.devices.TopicDemuxOuterClass.getDescriptor(),
        }, assigner);
    internal_static_ubii_sessions_TopicInputMapping_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_sessions_TopicInputMapping_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_TopicInputMapping_descriptor,
        new java.lang.String[] { "InputName", "Topic", "TopicMux", "TopicSource", });
    internal_static_ubii_sessions_TopicInputMappingList_descriptor =
      getDescriptor().getMessageTypes().get(1);
    internal_static_ubii_sessions_TopicInputMappingList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_TopicInputMappingList_descriptor,
        new java.lang.String[] { "Elements", });
    internal_static_ubii_sessions_TopicOutputMapping_descriptor =
      getDescriptor().getMessageTypes().get(2);
    internal_static_ubii_sessions_TopicOutputMapping_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_TopicOutputMapping_descriptor,
        new java.lang.String[] { "OutputName", "Topic", "TopicDemux", "TopicDestination", });
    internal_static_ubii_sessions_TopicOutputMappingList_descriptor =
      getDescriptor().getMessageTypes().get(3);
    internal_static_ubii_sessions_TopicOutputMappingList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_TopicOutputMappingList_descriptor,
        new java.lang.String[] { "Elements", });
    internal_static_ubii_sessions_IOMapping_descriptor =
      getDescriptor().getMessageTypes().get(4);
    internal_static_ubii_sessions_IOMapping_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_IOMapping_descriptor,
        new java.lang.String[] { "ProcessingModuleId", "InputMappings", "OutputMappings", "ProcessingModuleName", });
    internal_static_ubii_sessions_IOMappingList_descriptor =
      getDescriptor().getMessageTypes().get(5);
    internal_static_ubii_sessions_IOMappingList_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_sessions_IOMappingList_descriptor,
        new java.lang.String[] { "Elements", });
    ubii.devices.TopicMuxOuterClass.getDescriptor();
    ubii.devices.TopicDemuxOuterClass.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
